Built-in body rules for mdtype.
Each rule lives in its own module and is trivially copy-pasteable as a template for
new rules in downstream crates. Add new rules here or in an external crate — never
in mdtype-core.
Modules
- forbid_
h1 body.forbid_h1— disallow any top-level#heading.- forbidden_
sections body.forbidden_sections— assert that named H2 headings do not appear.- required_
sections body.required_sections— assert that each named H2 heading exists.- section_
order body.section_order— assert ordering of required H2 headings.
Functions
- register_
stdlib - Return the set of factories for every stdlib rule. Register these with your
SchemaSourceso YAML schemas may reference their rule ids.